RESERVED_PREFIX = "harambe_reserved_"

PRICE_NOT_AVAILABLE_PHRASES = [
    "ask for pricing",
    "call for price",
    "check price in store",
    "coming soon",
    "contact for price",
    "contact us for price",
    "currently unavailable",
    "email for price",
    "free",
    "get a quote",
    "inquire for price",
    "login for price",
    "login to see price",
    "n/a",
    "n/a (not available)",
    "no price available",
    "not priced",
    "out of stock",
    "please call",
    "please contact",
    "price coming soon",
    "price hidden",
    "price not available",
    "price not disclosed",
    "price on application",
    "price on request",
    "price tbd (to be determined)",
    "price unavailable",
    "price upon inquiry",
    "price upon request",
    "pricing not provided",
    "quote",
    "request a quote",
    "see details for price",
    "see price after login",
    "sold out",
    "tbd",
    "tdb",
    "temporarily unavailable",
    "unavailable price",
    "variable price",
    "varies",
]

CURRENCY_MAP = {
    "ALL": "ALL",
    "AFN": "AFN",
    "ARS": "ARS",
    "AWG": "AWG",
    "AUD": "AUD",
    "AZN": "AZN",
    "BSD": "BSD",
    "BBD": "BBD",
    "BYN": "BYN",
    "BZD": "BZD",
    "BMD": "BMD",
    "BOB": "BOB",
    "BAM": "BAM",
    "BWP": "BWP",
    "BGN": "BGN",
    "BRL": "BRL",
    "BND": "BND",
    "KHR": "KHR",
    "CAD": "CAD",
    "KYD": "KYD",
    "CLP": "CLP",
    "CNY": "CNY",
    "COP": "COP",
    "CRC": "CRC",
    "CUP": "CUP",
    "CZK": "CZK",
    "DKK": "DKK",
    "DOP": "DOP",
    "XCD": "XCD",
    "EGP": "EGP",
    "SVC": "SVC",
    "EUR": "EUR",
    "FKP": "FKP",
    "FJD": "FJD",
    "GHS": "GHS",
    "GIP": "GIP",
    "GTQ": "GTQ",
    "GGP": "GGP",
    "GYD": "GYD",
    "HNL": "HNL",
    "HKD": "HKD",
    "HUF": "HUF",
    "ISK": "ISK",
    "INR": "INR",
    "IDR": "IDR",
    "IRR": "IRR",
    "IMP": "IMP",
    "ILS": "ILS",
    "JMD": "JMD",
    "JPY": "JPY",
    "JEP": "JEP",
    "KZT": "KZT",
    "KPW": "KPW",
    "KRW": "KRW",
    "KGS": "KGS",
    "LAK": "LAK",
    "LBP": "LBP",
    "LRD": "LRD",
    "MKD": "MKD",
    "MYR": "MYR",
    "MUR": "MUR",
    "MXN": "MXN",
    "MNT": "MNT",
    "MZN": "MZN",
    "NAD": "NAD",
    "NPR": "NPR",
    "ANG": "ANG",
    "NZD": "NZD",
    "NIO": "NIO",
    "NGN": "NGN",
    "NOK": "NOK",
    "OMR": "OMR",
    "PKR": "PKR",
    "PAB": "PAB",
    "PYG": "PYG",
    "PEN": "PEN",
    "PHP": "PHP",
    "PLN": "PLN",
    "QAR": "QAR",
    "RON": "RON",
    "RUB": "RUB",
    "SHP": "SHP",
    "SAR": "SAR",
    "RSD": "RSD",
    "SCR": "SCR",
    "SGD": "SGD",
    "SBD": "SBD",
    "SOS": "SOS",
    "ZAR": "ZAR",
    "LKR": "LKR",
    "SEK": "SEK",
    "CHF": "CHF",
    "SRD": "SRD",
    "SYP": "SYP",
    "TWD": "TWD",
    "THB": "THB",
    "TTD": "TTD",
    "TRY": "TRY",
    "TVD": "TVD",
    "UAH": "UAH",
    "AED": "AED",
    "GBP": "GBP",
    "USD": "USD",
    "UYU": "UYU",
    "UZS": "UZS",
    "VEF": "VEF",
    "VND": "VND",
    "YER": "YER",
    "ZWD": "ZWD",
    "GEL": "GEL",
    "$": "USD",
    "€": "EUR",
    "£": "GBP",
    "¥": "JPY",
    "₹": "INR",
    "₩": "KRW",
    "A$": "AUD",
    "C$": "CAD",
    "NZ$": "NZD",
    "S$": "SGD",
    "HK$": "HKD",
    "R$": "BRL",
    "Z$": "ZWL",
    "₽": "RUB",
    "₺": "TRY",
    "₦": "NGN",
    "₫": "VND",
    "₱": "PHP",
    "₡": "CRC",
    "₭": "LAK",
    "₮": "MNT",
    "₲": "PYG",
    "฿": "THB",
    "₪": "ILS",
    "৳": "BDT",
    "zł": "PLN",
    "៛": "KHR",
    "kr": "NOK",
    "kr.": "SEK",
    "Kč": "CZK",
    "RM": "MYR",
    "R": "ZAR",
    "د.إ": "AED",
    "د.م.": "MAD",
    "د.ك": "KWD",
    "﷼": "IRR",
    "Bs": "VEF",
    "Bs.": "VEF",
    "S/.": "PEN",
    "B/.": "PAB",
    "Lek": "ALL",
    "؋": "AFN",
    "₼": "AZN",
    "Br": "BYN",
    "BZ$": "BZD",
    "$b": "BOB",
    "KM": "BAM",
    "P": "BWP",
    "лв": "BGN",
    "RD$": "DOP",
    "¢": "GHS",
    "J$": "JMD",
    "ден": "MKD",
    "₨": "MUR",
    "Gs": "PYG",
    "lei": "RON",
    "Дин.": "RSD",
    "NT$": "TWD",
    "TT$": "TTD",
    "₴": "UAH",
    "$U": "UYU",
    "DH": "DZD",
    "Ft": "HUF",
    "MK": "MWK",
    "MT": "MZN",
    "L": "RON",
    "T": "KZT",
    "VT": "VUV",
    "Q": "GTQ",
    "ƒ": "ANG",
    "Rp": "IDR",
    "S": "SOS",
    "₾": "GEL",
}
